#
# spec file for package python-ldap3
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-ldap3
Version:        2.2.4
Release:        1.1
Summary:        A strictly RFC 4511 conforming LDAP V3 pure Python client
License:        LGPL-3.0
Group:          Development/Languages/Python
Url:            https://github.com/cannatag/ldap3
Source:         https://pypi.io/packages/source/l/ldap3/ldap3-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module pyasn1 >= 0.1.8}
Requires:       python-pyasn1 >= 0.1.8
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
ldap3 is a strictly RFC 4511 conforming LDAP V3 pure Python **client**.
The same codebase works with Python, Python 3, PyPy and PyPy3.

This project was formerly named **python3-ldap**.
The name has been changed to avoid confusion with the python-ldap library.

%prep
%setup -q -n ldap3-%{version}
sed -i 's/\r$//' COPYING.LESSER.txt COPYING.txt README.rst LICENSE.txt

%build
%python_build

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

# Files needed for tests are not included in tar.gz
# %check
# nosetests -s test

%files %{python_files}
%defattr(-,root,root,-)
%doc COPYING.LESSER.txt COPYING.txt LICENSE.txt README.rst
%{python_sitelib}/ldap3
%{python_sitelib}/ldap3-%{version}-py*.egg-info

%changelog
* Wed May 10 2017 michael@stroeder.com
- Update to version 2.2.4
  - leading and trailing spaces in server name don't raise exception anymore
  - DitContentRule is properly read from the schema
  - added validator for Active Directory timestamp
  - Mock strategies raise an exception if a non-bytes value is added to the schema when no offline schema is provided (str and int are automatically converted)
  - added custom_validators property to Mock strategies
  - modifying objectClass with bytes values doesn't raise an exception anymore (but it may fail anyway because of server constraints)
  - ensure that config sequence parameters are properly set
  - allow case insensitive attribute and class names in config parameters
  - added server.schema.is_valid() to check if the schema is available
  - empty schema properties are set to empty dict() instead of None
  - schema definitions with traling and leading spaces are now properly parsed and don't raise an LDAPSchemaError exception anymore
  - fixed error when flaky servers (OpenLDAP) don't return the correct response with StartTls
* Wed May  3 2017 michael@stroeder.com
- Update to version 2.2.3
  - abstraction layer query converts int values to string (thanks dgadmin)
  - CaseInsensitiveDictWithAlias doesn't raise an exception anymore if alias is set multiple times to the same key
  - friendly names in AttrDef are properly managed when performing commits in Writer cursors
  - no more errors when server returns an empty schema (thanks Glen)
  - range attributes in entries are properly recognized when auto_range is False
  - fixed random errors in auto_range searches (thanks James)
  - fixed checking of malformed schema
  - added configuration parameter IGNORE_MALFORMED_SCHEMA to not raise exception for servers that don't follow the LDAP RFCs (defaults to False)
  - test config moved to test/config.py
  - testcase_id generated randomly for each test
  - added ATTRIBUTES_EXCLUDED_FROM_OBJECT_DEF parmeter to exclude some attribute from automatic populate of ObjectDef in Abstract Layer (helpful for AD)
  - added IGNORED_MANDATORY_ATTRIBUTES_IN_OBJECT_DEF parmeter to exclude some attribute from mandatory attribute list in ObjectDef in Abstract Layer (helpful for AD)
  - fixed error when using implicit assigning in WritableEntry
  - added LDAPInvalidValueError Exception
  - in Python 3 byte filter are converted to unicode before parsing
  - RESPONSE_DN_ENCODING parameter renamed to ADDITIONAL_ENCODINGS
  - to_unicode(value, encoding=None, additional_encodings=False) now checks for additional encoodings in ADDITIONAL_ENCODINGS list if additional_encoding is set to True
  - Reusable strategy uses not lazy Restartable connections
  . Reusable strategy doesn't keep requesting the schema
  - connection pool size in Reusable strategy defaults to 5
  - optimized usage of configuration parameters
* Fri Apr 14 2017 toddrme2178@gmail.com
- Update to version 2.2.2
  - PLAIN mechanism added to SASL authentication (thanks Janusz)
  - added RESULT_RESERVED return code (thanks Rak)
  - added RESPONSE_DN_ENCODING in config for flaky servers that return non utf-8 encoded DN. Set it to a list of encoding to sequentially try for decodign DNs.
  - removed StopIteration in generators (deprecated by PEP 479)
  - fixed a bug when converting AD datetimes on Windows systems
  - added compatibility with pyasn1 0.2.3
  - fixed NTLM authentication with pyasn1 0.2.3
  - fixed an error when installing via executable on Windows (thanks TrumSteven)
  - added 'raw_dn' key in search response dictionary. It contains the DN byte value returned for DN by the server
  - attributes with ";binary" tag can now be retrieved in abstraction layer with the usual entry.atttribute syntax
  - updated tests for OpenLDAP
  - fixed error when in add/remove extend operation for case mismatch in user or group dn
  - integer validator now automatically convert valid string numbers to int
  - invalid timezone are checked when validating Generalized Time Format
  - added test cases for validators
- Implement single-spec version
* Thu Mar  9 2017 joop.boonen@opensuse.org
- Build version 2.2.1
  - 2.2.1 2017.02.12
  - tested against pyasn1 0.2.2 (thanks Ilya)
  - get_response() has an optional new parameter "get_request" to return the request too, helpful in asynchronous strategies
  - connection.request, connection.response and connection result are now properly blanked in async strategies
  - ldap3.utils.dn.safe_dn() now checks for AD names only if no equal sign is present in the dn
  - abstraction layer properly works with asynchronous strategies
  - added a named tuple "Operation" used to store the request, result and response of an LDAP operation in Cursor history
  - cursors in the Abstraction Layer keep history of executed LDAP operations for the last Cursor operation in the cursor.operation property
  - Cursors in the Abstraction Layer keep history of errors for the last Cursor operation in the cursor.errors property
  - if any error has occurred in the last operation of a Cursor the cursor.failed property is set to True
  - added a named tuple "Operation" for storing request, result and response of an LDAP operation in Cursor history
  - Cursor honours raise_exception parameter of the Connection.
  - Cursor commit() return True if operations are successful and False if not. All pending commits are executed even if some fail
  - new entries that have no additional mandatory attributes other those defined in dn are properly managed in Writers (thanks Matt)
  - CaseInsensitiveDict now properly strips blanks from keys
  - updated hashing alghoritm SHA to SHA1 (thanks Satoh)
  - added match_dn(dn) to Cursor for matching entries with specified text in DN
  - added match(attributes, value) for matching entries with specified value in one or more attribute values. It checks values and raw_values
  - Cursors have simple match capability. When key is a string Cursor tries to match it against the DN of entries found.
  - 2.2.0 2017.01.16
  - tested againsts Python 3.6.0, Python 2.7.13 and Python 2.6.6
  - updated docs regarding search response attributes (thanks James)
  - fixed LDIF representation for operation_to_ldif (thanks m7four)
  - fixed rebind for pooled connections
  - fixed custom sort order in LDIF representation of entry
  - added Active Directory GUID syntax for safe_dn() (thanks dinhngtu)
  - added pre-post read control (thanks Elizabeth)
  - added add_members_to_groups in microsoft.extend namespace for Active Directory
  - added remove_members_to_groups in microsoft.extend namespace for Active Directory
  - refactored internal extend.microsoft and extend.novell structures
  - fixed auto_escape for extended characters (thanks asand3r)
  - validators now transform the Python value to a valid LDAP value when appropriate (thanks Sjd-Risca)
  - added validator for boolean types
  - added validator for date types
  - fixed representation of binary data in Abstraction Layer for Python 2
  - added auto_encode parameter to Connection object (defaults to True)
  - limited auto_escape feature only to filter values
  - escape_filter_chars doens't try anymore to guess if the value is already escaped.
  - added ldap3.conv.is_filter_safe() (thanks Robert)
  - added auto_escape parameter to connection.search() to override connection auto_escape behaviour (defaults to None)
  - auto_escape is not applied to filter value if already escaped
  - automatically encode output to stdout encoding for repr() and str() (for printing and logging attributes values).
  - binary data are converted to a hex values string in repr() and str() (for printing and logging attributes values).
  - auto_encoding is performed only for well known attribute types that use Unicode format in LDAP
  - CLASSES_EXCLUDED_FROM_CHECK and ATTRIBUTES_EXCLUDED_FROM_CHECK moved to ldap3.utils.config and made available via get_config_parameter()
  - added UTF8_ENCODED_SYNTAXES in ldap3.config.utils and made available via get_config_parameter()
  - added UTF8_ENCODED_TYPES in ldap3.config.utils and made available via get_config_parameter()
  - config parameters made available only via get_config_parameters()
  - removed to_bytes() and check_escape() from ldap3.utils.conv (ambiguous functions)
  - added connection.request to MockSync (thanks Fabian)
  - tags are properly managed in add, compare and modify requests (thanks guidow)
  - in Mock strategies single-valued attributes are properly managed
  - in Mock strategies attributes type names are properly managed
  - implemented extended operation machinery in MockBase
  - implemented WhoAmI [RFC4532] in Mock strategies
  - implemented GetBindDn [NOVELL] in Mock strategies
  - implemented operational attributes machinery in MockBase
  - implemented entryDN [RFC5020] operational attribute in MockBase
  - Sphinx updated to 1.5.1
  - 2.1.1 2016.11.18
  - Mock strategy uses case insensitive matching when appropriate
  - fixed error when adding a virtual attribute in the abstract Entry object
  - fixed error messages in Entry moving and renaming
  - Reverted default connection strategy to SYNC (thanks Mauro)
  - Fixed tutorials (thanks Mauro)
  - Fixed checking of schema in ObjectDef (thanks Pierre)
  - Fixed checking of stdin in config (thanks Oleg)
  - fixed commit of entry with async strategies
  - fixed reading of entries in async strategies
  - added cipher argument to Tls (thanks Nicolas)
  - fixed bug when using the abstraction layer with lazy connections
  - fixed case matching while adding new entry in Writer cursor (thanks t0neg)
  - disabled auto_escape for byte values
  - fixed auto_escape for python 2
  - fixed tutorials (thanks Ivano)
  - 2.1.0 2016.11.03
  - changed default Connection strategy from SYNC to RESTARTABLE
  - enable automatic escaping of assertion values
  - fixed decoding error with check_name=False
  - added auto_escape parameter in connection, for trying automatic filter and attribute values escape
  - fixed checking of schema in MockBase
  - SASLBindInProgress doesn't raise an exception anymore with raise_exceptions=True
  - standard formatters are applied in mocking strategies when serching for exact match
  - 2.0.9 2016.10.28
  - removed sanitization of DN in bind operation because some servers accept non standard DN for Simple Bind
  - 2.0.8 2016.10.28
  - included referral caching (thanks TWAC)
  - 2.0.7 2016.10.27
  - FIRST RELEASE OF LDAP3 V2
  - changed signature of ldap3.abstract.Reader object
  - removed search_size_limit(), search_time_limit() and search_types_only in the Reader cursor
  - fixed SASL in progress error (thanks Styleex)
  - fixed ALL_ATTRIBUTES in MOCK_SYNC strategy (thanks Belgarion)
  - ncorrect attribute type error message now includes the name of the attribute (Thanks Andrej)
  - relaxed dn checking for Active Directory UserPrincipalName
  - relaxed dn checking for Active Directory SamAccountName
  - added checking of attribute name in add, compare and search operations
  - added checking of class name in add operation
  - renamed exception LDAPTypeError to LDAPAttributeError
  - in sync strategies LDAP operations populate the last_error attribute of the connection in case of not RESULT_SUCCESS
  - connection.return_empty_attributes defaults to True
  - escaped filter by default
  - fixed escaping of filter
  - add move and rename to abstraction layer entry
  - ldap3 namespace decluttered
  - RESULT_CODES moved to ldap3.core.results
  - compatability constants removed
  - exceptions removed from ldap3 namespace, defined in ldap3.core.exceptions only
  - ADDRESS_INFO_REFRESH_TIME is now configurable via set_config_parameter
  - Operational attribute prefix set to 'OA_'
  - Allows cert and key file in the same file (thanks Jan-Philip)
  - Removed logging info when logging is disabled (thanks Dan)
  - Updated copyright notice
  - Refactored abstraction layer with full support for CRUD (Create, Read, Update, Delete) abstract operations
  - Added WritableEntry and WritableAttribute to abstraction layer
  - Added standard validators for attribute types and syntaxes defined in the standard LDAP schema
  - Added custom validators for attribute values
  - Added update capability to abstraction layer
  - Fixed typo in docs (thanks Gerardwx)
  - Fixed Object and Attribute representation in schema (superior class not shown)
  - ObjectDef automatically populates attributes from schema, following object_class hierarchy
  - Added attributes parameter to search* methods of Cursor, so that only needed attributes are read even if attr_defs defines more
  - Fixed connect_timeout not honored while wrapping socket in tls (thanks Kyle)
  - Added 'set' to SEQUENCE_TYPES (thanks Christian)
  - Entries returned by search are now writable via the abstraction layer
  - LDAPReaderError exception renamed to LDAPCursorError
  - auto_range parameter in Connection defaults to True (thanks Ashley)
  - get_info defaults to SCHEMA while defining Server object
  - Included ordereddict 1.1 (# Copyright (c) 2009 Raymond Hettinger) in ldap3.utils.ordDict for backporting OrderedDict in Python 2.6
  - Added config parameter RESET_AVAILABILITY_TIMEOUT to reinsert invalid address in candidate_addresses while checking connection, defaults to 5 seconds
  - Fixed inability to connect to a server if the connection starts when the server is unavailable and then it becomes available again
  - All DNs are sanitized if connection.check_names is True
  - LDAPControlsError exception renamed to LDAPControlError
  - LDAPChangesError exception renamed to LDAPChangeError
  - The following older constants in ldap3 have been removed, please use the suggested ones:
  - AUTH_ANONYMOUS = ANONYMOUS
  - AUTH_SIMPLE = SIMPLE
  - AUTH_SASL = SASL
  - SEARCH_SCOPE_BASE_OBJECT = BASE
  - SEARCH_SCOPE_SINGLE_LEVEL = LEVEL
  - SEARCH_SCOPE_WHOLE_SUBTREE = SUBTREE
  - SEARCH_NEVER_DEREFERENCE_ALIASES = DEREF_NEVER
  - SEARCH_DEREFERENCE_IN_SEARCHING = DEREF_SEARCH
  - SEARCH_DEREFERENCE_FINDING_BASE_OBJECT = DEREF_BASE
  - SEARCH_DEREFERENCE_ALWAYS = DEREF_ALWAYS
  - STRATEGY_SYNC = SYNC
  - STRATEGY_ASYNC_THREADED = ASYNC
  - STRATEGY_LDIF_PRODUCER = LDIF
  - STRATEGY_SYNC_RESTARTABLE = RESTARTABLE
  - STRATEGY_REUSABLE_THREADED = REUSABLE
  - STRATEGY_MOCK_SYNC = MOCK_SYNC
  - STRATEGY_MOCK_ASYNC = MOCK_SYNC
  - POOLING_STRATEGY_FIRST = FIRST
  - POOLING_STRATEGY_ROUND_ROBIN = ROUND_ROBIN
  - POOLING_STRATEGY_RANDOM = RANDOM
  - GET_NO_INFO = NONE
  - GET_DSA_INFO = DSA
  - GET_SCHEMA_INFO = SCHEMA
  - GET_ALL_INFO = ALL
* Sun Oct  2 2016 mardnh@gmx.de
- Update to version 1.4.0
  - upstream does not provide a changelog
- Fix source-url
- Specfile cleanup
* Thu Jun 23 2016 rhafer@suse.de
- Fix License string to confirm with spdx.org
* Wed Sep  9 2015 tbechtold@suse.com
- Initial packaging (version 0.9.8.8)
